## Description
Brief description of changes

## Type of Change
- [ ] Bug fix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to not work as expected)
- [ ] Documentation update
- [ ] Performance improvement
- [ ] Code refactoring

## Related Issues
Fixes #(issue number)
Closes #(issue number)
Related to #(issue number)

## Changes Made
- [ ] List the main changes made
- [ ] Include any new files added
- [ ] Include any files modified
- [ ] Include any files removed

## Testing
- [ ] Tests pass locally
- [ ] New tests added for new functionality
- [ ] All existing tests still pass
- [ ] Manual testing completed

### Test Coverage
- [ ] Unit tests added/updated
- [ ] Integration tests added/updated
- [ ] Performance tests added/updated (if applicable)

## Code Quality
- [ ] Code follows style guidelines
- [ ] Self-review completed
- [ ] Code is properly commented
- [ ] Type hints added where appropriate
- [ ] No linting errors

## Documentation
- [ ] README updated (if needed)
- [ ] API documentation updated
- [ ] Inline comments added/updated
- [ ] Examples updated (if applicable)

## Performance Impact
- [ ] No performance impact
- [ ] Performance improvement
- [ ] Performance regression (explain below)

If there's a performance impact, please explain:

## Breaking Changes
- [ ] No breaking changes
- [ ] Breaking changes (explain below)

If there are breaking changes, please explain:

## Checklist
- [ ] My code follows the style guidelines of this project
- [ ] I have performed a self-review of my own code
- [ ] I have commented my code, particularly in hard-to-understand areas
- [ ] I have made corresponding changes to the documentation
- [ ] My changes generate no new warnings
- [ ] I have added tests that prove my fix is effective or that my feature works
- [ ] New and existing unit tests pass locally with my changes
- [ ] Any dependent changes have been merged and published

## Additional Notes
Any additional information that reviewers should know about this PR.

## Screenshots (if applicable)
Add screenshots to help explain your changes.

## Reviewer Notes
Any specific areas you'd like reviewers to focus on or questions you have about the implementation.
